Bug#896487: datamash FTBFS on !x86/ia64: FAIL: tests/datamash-output-format

2018-10-12 Thread Sven Joachim
Control: tags -1 + fixed-upstream patch

On 2018-04-21 19:05 +0300, Adrian Bunk wrote:

> Source: datamash
> Version: 1.3-1
> Severity: serious
>
> https://buildd.debian.org/status/package.php?p=datamash&suite=sid
>
> ...
> FAIL: tests/datamash-output-format
> ==
>
> datamash (GNU datamash) 1.3
> Copyright (C) 2018 Assaf Gordon
> License GPLv3+: GNU GPL version 3 or later 
> .
> This is free software: you are free to change and redistribute it.
> There is NO WARRANTY, to the extent permitted by law.
>
> Written by Assaf Gordon.
> r1...
> r2...
> r3...
> r4...
> r5...
> r6...
> r7...
> r8...
> r9...
> f1...
> f2...
> f3...
> f4...
> f5...
> f6...
> f7...
> g1...
> g2...
> g3...
> g4...
> g5...
> g6...
> g7...
> e1...
> e2...
> a1...
> datamash-output-format.pl: test a1: stdout mismatch, comparing a1.2 
> (expected) and a1.O (actual)
> *** a1.2  Sun Apr 15 12:44:18 2018
> --- a1.O  Sun Apr 15 12:44:18 2018
> ***
> *** 1 
> ! 0x8.000p-3
> --- 1 
> ! 0x1.000p+0
> m1...
> m2...
> FAIL tests/datamash-output-format.pl (exit status: 1)
> ...
> 
> Testsuite summary for GNU datamash 1.3
> 
> # TOTAL: 20
> # PASS:  17
> # SKIP:  2
> # XFAIL: 0
> # FAIL:  1
> # XPASS: 0
> # ERROR: 0
> 
> See ./test-suite.log
> Please report to assafgor...@gmail.com
> 
> Makefile:3168: recipe for target 'test-suite.log' failed
> make[5]: *** [test-suite.log] Error 1

Should be fixed by commit d446dba317[1] ("tests: fix --format='%4000f'
expected output").

Cheers,
   Sven


1. 
https://git.savannah.gnu.org/cgit/datamash.git/commit/?id=d446dba317aa067440d6312d955d523129949327

>From d446dba317aa067440d6312d955d523129949327 Mon Sep 17 00:00:00 2001
From: Assaf Gordon 
Date: Thu, 22 Mar 2018 11:00:34 -0600
Subject: [PATCH 1/1] tests: fix --format='%4000f' expected output

Can be 1.09... or 1.08999, depending on representation.

* tests/datamash-output-format.pl: Check only the first 5 digits.
---
 tests/datamash-output-format.pl | 9 +
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/tests/datamash-output-format.pl b/tests/datamash-output-format.pl
index 52c68a2..ca99bb0 100755
--- a/tests/datamash-output-format.pl
+++ b/tests/datamash-output-format.pl
@@ -98,12 +98,13 @@ my @Tests =
{OUT => "0" x 3999 . "1\n"}],
 
   # due to binary floating representation, some decimal point digits won't be
   # zero (e.g. 1.09052345325432000...).
   # The OUT_SUBST replaces exactly 3994 digits (as expected from the format)
   # with an "X".
   ['m2', '--format "%.4000f"   sum 1',  {IN_PIPE=>$in1},
-   {OUT => "1.09X\n"},
-   {OUT_SUBST => 's/^(1\.09)([0-9]{3994})$/\1X/'}],
+   {OUT => "1.0X\n"},
+   {OUT_SUBST => 's/^(1\.0)([0-9]{3995})$/\1X/'}],
 
 );
 
@@ -98,12 +98,13 @@ my @Tests =
 
   # due to binary floating representation, some decimal point digits won't be
-  # zero (e.g. 1.09052345325432000...).
-  # The OUT_SUBST replaces exactly 3994 digits (as expected from the format)
+  # zero (e.g. 1.09052345325432000... or
+  # 1.0899...).
+  # The OUT_SUBST replaces exactly 3995 digits (as expected from the format)
   # with an "X".
   ['m2', '--format "%.4000f"   sum 1',  {IN_PIPE=>$in1},
-- 
2.19.1



Processed: Re: Bug#896487: datamash FTBFS on !x86/ia64: FAIL: tests/datamash-output-format

2018-10-12 Thread Debian Bug Tracking System
Processing control commands:

> tags -1 + fixed-upstream patch
Bug #896487 [src:datamash] datamash FTBFS on !x86/ia64: FAIL: 
tests/datamash-output-format
Added tag(s) fixed-upstream and patch.

-- 
896487: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=896487
Debian Bug Tracking System
Contact ow...@bugs.debian.org with problems



Bug#896487: datamash FTBFS on !x86/ia64: FAIL: tests/datamash-output-format

2018-04-21 Thread Adrian Bunk
Source: datamash
Version: 1.3-1
Severity: serious

https://buildd.debian.org/status/package.php?p=datamash&suite=sid

...
FAIL: tests/datamash-output-format
==

datamash (GNU datamash) 1.3
Copyright (C) 2018 Assaf Gordon
License GPLv3+: GNU GPL version 3 or later .
This is free software: you are free to change and redistribute it.
There is NO WARRANTY, to the extent permitted by law.

Written by Assaf Gordon.
r1...
r2...
r3...
r4...
r5...
r6...
r7...
r8...
r9...
f1...
f2...
f3...
f4...
f5...
f6...
f7...
g1...
g2...
g3...
g4...
g5...
g6...
g7...
e1...
e2...
a1...
datamash-output-format.pl: test a1: stdout mismatch, comparing a1.2 (expected) 
and a1.O (actual)
*** a1.2Sun Apr 15 12:44:18 2018
--- a1.OSun Apr 15 12:44:18 2018
***
*** 1 
! 0x8.000p-3
--- 1 
! 0x1.000p+0
m1...
m2...
FAIL tests/datamash-output-format.pl (exit status: 1)
...

Testsuite summary for GNU datamash 1.3

# TOTAL: 20
# PASS:  17
# SKIP:  2
# XFAIL: 0
# FAIL:  1
# XPASS: 0
# ERROR: 0

See ./test-suite.log
Please report to assafgor...@gmail.com

Makefile:3168: recipe for target 'test-suite.log' failed
make[5]: *** [test-suite.log] Error 1